﻿# -*- coding: UTF-8 -*-

import api
import controlTypes
import winUser
from keyboardHandler import KeyboardInputGesture
from NVDAObjects.IAccessible import IAccessible


class BTSyncSetup1(IAccessible):
	"""Custom class for the first BTSync setup screen"""

	standardSetup = 1761
	iHaveASecret = 1762
	enterSecretHere = 1763
	iHaveReadAndAgree = 1734
	skipButton = 1586
	nextButton = 1587

	def leftMouseClick(self, obj, twice=False):
		# Store the current X-Y position of the mouse pointer.
		oldX, oldY = winUser.getCursorPos()
		# Move the mouse pointer to the location of obj.
		api.moveMouseToNVDAObject(obj)
		# Perform a left mouse click.
		winUser.mouse_event(winUser.MOUSEEVENTF_LEFTDOWN, 0, 0, None, None)
		winUser.mouse_event(winUser.MOUSEEVENTF_LEFTUP, 0, 0, None, None)
		if twice:
			winUser.mouse_event(winUser.MOUSEEVENTF_LEFTDOWN, 0, 0, None, None)
			winUser.mouse_event(winUser.MOUSEEVENTF_LEFTUP, 0, 0, None, None)
		#/if
		# Move the mouse pointer to it's original X-Y position.
		winUser.setCursorPos(oldX, oldY)
	#/def

	def script_leftArrowPressed(self, gesture):
		# What to do when left arrow is pressed.
		if self.windowControlID in [self.standardSetup, self.iHaveASecret, self.iHaveReadAndAgree, self.nextButton]:
			return
		#/if
		# Send the gesture through to the application.
		gesture.send()
	#/def

	def script_rightArrowPressed(self, gesture):
		# What to do when right arrow is pressed.
		if self.windowControlID in [self.standardSetup, self.iHaveASecret, self.iHaveReadAndAgree, self.skipButton]:
			return
		#/if
		# Send the gesture through to the application.
		gesture.send()
	#/def

	def script_upArrowPressed(self, gesture):
		# What to do when up arrow is pressed.
		try:
			if self.windowControlID == self.iHaveASecret:
				return self.leftMouseClick(self.parent.previous.firstChild)
			#/if
			elif self.windowControlID in [self.standardSetup, self.iHaveReadAndAgree, self.skipButton, self.nextButton]:
				return
			#/elif
		#/try
		except AttributeError:
			pass
		#/except
		# Send the gesture through to the application.
		gesture.send()
	#/def

	def script_downArrowPressed(self, gesture):
		# What to do when down arrow is pressed.
		try:
			if self.windowControlID == self.standardSetup:
				return self.leftMouseClick(self.parent.next.firstChild)
			#/if
			elif self.windowControlID in [self.iHaveASecret, self.iHaveReadAndAgree, self.skipButton, self.nextButton]:
				return
			#/elif
		#/try
		except AttributeError:
			pass
		#/except
		# Send the gesture through to the application.
		gesture.send()
	#/def

	def script_shiftTabPressed(self, gesture):
		# What to do when shift+tab is pressed.
		try:
			if self.windowControlID==self.standardSetup or self.windowControlID==self.iHaveASecret:
				checkBox = self.parent.parent.lastChild.previous.firstChild
				if not controlTypes.STATE_CHECKED in checkBox.states:
					self.leftMouseClick(checkBox, twice=True)
				#/if
				else:
					KeyboardInputGesture.fromName("leftArrow").send()
				#/else
				return
			#/if
			elif self.windowControlID==self.iHaveReadAndAgree:
				if self.parent.previous.firstChild.windowControlID == self.enterSecretHere:
					self.leftMouseClick(self.parent.previous.firstChild)
				#/if
				else:
					self.leftMouseClick(self.parent.previous.previous.firstChild)
				#/else
				return
			#/elif
			elif self.windowControlID==self.enterSecretHere:
				return self.leftMouseClick(self.parent.previous.firstChild)
			#/elif
			elif self.windowControlID == self.nextButton:
				return self.leftMouseClick(self.parent.parent.firstChild.firstChild.lastChild.previous.firstChild, twice=True)
			#/elif
		#/try
		except AttributeError:
			pass
		#/except
		# Send the gesture through to the application.
		gesture.send()
	#/def

	def script_tabPressed(self, gesture):
		# What to do when tab is pressed.
		try:
			if self.windowControlID == self.iHaveASecret:
				return self.leftMouseClick(self.parent.next.firstChild)
			#/if
			elif self.windowControlID == self.standardSetup:
				return self.leftMouseClick(self.parent.next.next.firstChild, twice=True)
			#/elif
			elif self.windowControlID == self.enterSecretHere:
				return self.leftMouseClick(self.parent.next.firstChild, twice=True)
			#/elif
			elif self.windowControlID == self.skipButton:
				obj = self.parent.parent.firstChild.firstChild.firstChild.next.next.next.firstChild
				if not controlTypes.STATE_CHECKED in obj.states:
					obj = obj.parent.previous.firstChild
				#/if
				return self.leftMouseClick(obj)
			#/elif
		#/try
		except AttributeError:
			pass
		#/except
		# Send the gesture through to the application.
		gesture.send()
	#/def

	def initOverlayClass(self):
		gestures = {
			"kb:upArrow": "upArrowPressed",
			"kb:downArrow": "downArrowPressed",
			"kb:shift+tab": "shiftTabPressed",
			"kb:tab": "tabPressed",
		} #/gestures
		for gesture, func in gestures.items():
			self.bindGesture(gesture, func)
		#/for
		if self.windowControlID == self.enterSecretHere:
			self.name = self.appModule.labels.get(self.enterSecretHere)
		#/if
		else:
			self.bindGesture("kb:leftArrow", "leftArrowPressed")
			self.bindGesture("kb:rightArrow", "rightArrowPressed")
		#/else
	#/def
#/class
